@@ -1,18 +1,39 @@
 #!/bin/bash -e
 
-. "${0%/*}"/travis/lib.sh
+# NB: This script is normally run in a GNU environment (e.g. Linux), but we also run it on other
+# systems (e.g. macOS) as part of our automated CI.  So a little care must be taken.
+
+cd "${0%/*}" || exit 1
 
 m4dir="autotools/m4"
 
-v rm -rf autotools
-if [[ $1 != "--from=make" ]] ; then
-	v ${MAKE:-make} autotools-update
+: ${MAKE:=make}
+
+FROM_TOOL=
+while [[ $# -gt 0 ]] ;do
+	case $1 in
+	--from=*) FROM_TOOL=${1#*=};;
+	-x|--debug) set -x;;
+	*) break;;
+	esac
+	shift
+done
+
+if [[ $# -ne 0 ]] ; then
+	echo "Usage: $0" >&2
+	exit 1
+fi
+
+rm -rf autotools
+if [[ ${FROM_TOOL} != "make" ]] ; then
+	${MAKE} autotools-update
 fi
 
 # reload the gnulib code if possible
-PATH=/usr/local/src/gnu/gnulib:${PATH}
+PATH="${PWD}/gnulib:${PWD}/../gnulib:/usr/local/src/gnu/gnulib:${PATH}"
 mods="
 	alloca
+	euidaccess
 	faccessat
 	fdopendir
 	fstatat
@@ -25,6 +46,7 @@ mods="
 	readlinkat
 	renameat
 	stat-time
+	stpcpy
 	strcasestr-simple
 	strncat
 	symlinkat
@@ -33,13 +55,13 @@ mods="
 	utimensat
 	vasprintf-posix
 "
-v --fold="gnulib-tool" gnulib-tool \
+gnulib-tool \
 	--source-base=autotools/gnulib --m4-base=autotools/m4 \
 	--import \
 	${mods}
 
 # not everyone has sys-devel/autoconf-archive installed
-v tar xf travis/autotools.tar.xz
+tar xf travis/autotools.tar.xz
 has() { [[ " ${*:2} " == *" $1 "* ]] ; }
 import_ax() {
 	local macro content m4 lm4s=()
@@ -65,7 +87,7 @@ while [[ ${curr} -ne ${new} ]] ; do
 done
 
 export AUTOMAKE="automake --foreign"
-v autoreconf -i -f
+autoreconf -i -f
 
 if [[ -x ./test.sh ]] ; then
 	exec ./test.sh "$@"
