@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# PYTHON_ARGCOMPLETE_OK
 # Copyright 2012-2014 Gentoo Foundation
 # Copyright 2012-2014 Mike Frysinger <vapier@gentoo.org>
 # Copyright 2012-2014 The Chromium OS Authors
@@ -50,6 +51,11 @@ import sys
 
 assert sys.version_info >= (3, 6), f'Python 3.6+ required, but found {sys.version}'
 
+try:
+    import argcomplete
+except ImportError:
+    argcomplete = None
+
 from elftools.elf.elffile import ELFFile
 from elftools.common import exceptions
 
@@ -696,6 +702,9 @@ def GetParser():
     parser.add_argument('--skip-non-elfs',
                         action='store_true', default=False,
                         help='Skip plain (non-ELF) files instead of warning')
+    parser.add_argument('--skip-missing',
+                        action='store_true', default=False,
+                        help='Skip missing files instead of failing')
     parser.add_argument('-V', '--version',
                         action='version',
                         version='lddtree by Mike Frysinger <vapier@gentoo.org>',
@@ -739,6 +748,8 @@ def GetParser():
                        action='store_true', default=False,
                        help='Copy over plain (non-ELF) files instead of warn+ignore')
 
+    if argcomplete is not None:
+        argcomplete.autocomplete(parser)
     return parser
 
 
@@ -836,7 +847,8 @@ def main(argv):
                 _ActionCopy(options, elf)
 
         if not matched:
-            ret = 1
+            if not options.skip_missing:
+                ret = 1
             warn('%s: did not match any paths' % (path,))
 
     return ret
