@@ -1,22 +1,26 @@
 #!/bin/bash
 
+# NB: This script is expected to be run in a GNU environment (e.g. Linux).
+# So it is not written to be completely POSIX compliant.
+
 set -e
 
-if ! . /etc/init.d/functions.sh 2>/dev/null ; then
-	einfo() { printf ' * %b\n' "$*"; }
-	eerror() { einfo "$@" 1>&2; }
-fi
+einfo() { printf ' * %b\n' "$*"; }
+eerror() { einfo "$@" 1>&2; }
 die() { eerror "$@"; exit 1; }
-
 v() { printf '\t%s\n' "$*"; "$@"; }
 
 : ${MAKE:=make}
 
 CHECK=false
-if [[ $1 == "--check" ]] ; then
-	CHECK=true
+while [[ $# -gt 0 ]] ;do
+	case $1 in
+	--check) CHECK=true;;
+	-x|--debug) set -x;;
+	*) break;;
+	esac
 	shift
-fi
+done
 
 if [[ $# -ne 1 ]] ; then
 	die "Usage: $0 <ver>"
@@ -49,12 +53,13 @@ make -C man
 einfo "Building autotools ..."
 sed -i "/^AC_INIT/s:git:${ver}:" configure.ac
 sed -i "1iPV := ${ver}" Makefile
-LC_ALL=C ${MAKE} -s autotools >/dev/null
+SKIP_AUTOTOOLS_UPDATE=true LC_ALL=C ${MAKE} -s autotools >/dev/null
 rm -rf autom4te.cache
 
 popd >/dev/null
 
 einfo "Generating tarball ..."
+# The archive is small enough that -6 & -9 produce the same size.
 tar cf - "${p}" | xz > "${p}".tar.xz
 rm -r "${p}"
 
